##########################################################################################################################################
# FSA project FS307037 
# Development of a modular assessment framework to quantify the risk of AMR exposure via food products: example of chicken and lettuce
##########################################################################################################################################
# File Name:     global.R
# Description:   Global normal R script to store all the basic things that you need to use in your R shiny App. here we put all the "general" things like packages, datasets that need to be loaded etc. Objective: save some computation time as this script will be runned only once when using the app

# Company:       Ausvet Eu
# Author:        Céline Faverjon
# Role:          Epidemiologist
# Email:         celine@ausvet.eu
# Date:          31.10.21
##########################################################################################################################################


#packages of interest
packages = c("shiny", "shinydashboard","shinycssloaders","shinyWidgets",
             "reshape2", "tidyr", "ggplot2", "dplyr", "tidyverse", "plotly", "DT", "readxl", "ggrepel", "gridExtra", "ggfortify")

## load or install&load all
package.check <- lapply(
  packages,
  FUN = function(x) {
    if (!require(x, character.only = TRUE)) {
      install.packages(x, dependencies = TRUE)
      library(x, character.only = TRUE)
    }
  }
)

source("www/Function_dataSimulation.R")

  outputVar_chicken <- c("Prev_prod","C_prod",
                 "Prev_proc","C_proc",
                 "Prev_pproc","C_pproc",
                 "Prev_home_cook","C_home_cook", "P_home_cc","C_home_cc")
  outputTab_chicken <- as.data.frame(c("Prev_prod","C_prod",
                              "Prev_proc","C_proc",
                              "Prev_pproc","C_pproc",
                              "Prev_home_cook","C_home_cook", "P_home_cc","C_home_cc"))
  
  colnames(outputTab_chicken)<- c("variable")
  mod1 <-c("Prev_prod","C_prod")
  mod2 <-c("Prev_proc","C_proc")
  mod3<-c("Prev_pproc","C_pproc")
  mod4 <-c("C_home_cc", "C_home_cook", "Prev_home_cook", "P_home_cc")
  
  outputTab_chicken  <- outputTab_chicken  %>%
    mutate(Module = ifelse(variable %in% mod1, "Production", 
                           ifelse(variable %in% mod2, "Processing",
                                  ifelse(variable %in% mod3, "Post-processing","Home-preparation"))))%>%
    mutate(Module = factor(Module, levels = c('Production','Processing','Post-processing','Home-preparation')))
  outputTab_chicken$Definition <- c("Prevalence of products contaminated with AMR-gene-carrying bacteria arriving at the slaughterhouse",
                            "CFU of AMR-gene-carrying bacteria /contaminated product arriving at the slaughterhouse",
                            "Prevalence of products contaminated with AMR-gene-carrying bacteria after processing",
                            "CFU of AMR-gene-carrying bacteria /contaminated product after processing",
                            "Prevalence of food item contaminated with AMR-gene-carrying bacteria after post-processing",
                            "CFU of AMR-gene-carrying bacteria /contaminated food item after post-processing",
                            "Prevalence of food item contaminated with AMR-gene-carrying bacteria after cooking",
                            "CFU of AMR-gene-carrying bacteria ingested by contaminated food item",
                            "Probability of exposure to AMR-gene-carrying bacteria through cross contamination",
                            "CFU of AMR-gene-carrying bacteria ingested by cross contaminated food item")
  

  outputVar_lettuce <- c("Prev_prod","C_prod",
                 "Prev_proc","C_proc",
                 "Prev_pproc","C_pproc",
                 "Prev_home_cook","C_home_cook")
  outputTab_lettuce<- as.data.frame(c("Prev_prod","C_prod",
                              "Prev_proc","C_proc",
                              "Prev_pproc","C_pproc",
                              "Prev_home_cook","C_home_cook"))
  colnames(outputTab_lettuce)<- c("variable")
  
  mod1<-c("Prev_prod","C_prod")
  mod2<-c("Prev_proc","C_proc")
  mod3<-c("Prev_pproc","C_pproc")
  mod4<-c("Prev_home_cook", "C_home_cook")
  
  outputTab_lettuce <- outputTab_lettuce %>%
    mutate(Module = ifelse(variable %in% mod1, "Production", 
                           ifelse(variable %in% mod2, "Processing",
                                  ifelse(variable %in% mod3, "Post-processing","Home-preparation"))))%>%
    mutate(Module = factor(Module, levels = c('Production','Processing','Post-processing','Home-preparation')))
  outputTab_lettuce$Definition <- c("Prevalence of products contaminated with AMR-gene-carrying bacteria before processing",
                            "CFU of AMR-gene-carrying bacteria /contaminated product before processing",
                            "Prevalence of products contaminated with AMR-gene-carrying bacteria",
                            "CFU of AMR-gene-carrying bacteria /contaminated product",
                            "Prevalence of food item contaminated with AMR-gene-carrying bacteria",
                            "CFU of AMR-gene-carrying bacteria /contaminated food item",
                            "Prevalence of serving contaminated with AMR-gene-carrying bacteria after cooking",
                            "CFU of AMR-gene-carrying bacteria ingested by contaminated food item")
  
