##########################################################################################################################################
# FSA project FS307037 
# Development of a modular assessment framework to quantify the risk of AMR exposure via food products: example of chicken and lettuce
##########################################################################################################################################
# File Name:     server.R
# Description:   # Define server logic to read selected file 

# Company:       Ausvet Eu
# Author:        Céline Faverjon
# Role:          Epidemiologist
# Email:         celine@ausvet.eu
# Date:          31.10.21
##########################################################################################################################################


server <- function(input, output, session) {
  
  vals <- reactiveValues() #store all reactive values in this file
  
  # SCENARIO TAB --------------------------------------------------------------------------------------------------------------------------
  
  output$productSelection <- renderUI({
  # display selected variables specific to the selected food production chain
    if(input$Product == "Chicken"){
      tagList(
        #type of scalding used?
        selectInput(inputId="Scalding_type", label="What type of scalding is used?", choices=c("soft", "hard")),
        p("Soft scalding includes temperature ranging between 51-54°C with immersion times for 120 to 210s. Hard scalding includes water temperature from 60-66°C during an immersion time of 45-90s."),
        #Product sold with or without skin?
        selectInput(inputId="Meat_skin", label="Is the product sold with or without skin?", choices=c("skin off", "skin on"))
      )
      
    }else if(input$Product == "Lettuce"){
      #Product pre-washed or not?
      selectInput(inputId="Product_wash", label="Is the lettuce pre-washed or not?", choices=c("pre-washed", "not pre-washed"))
      
    }
  })
  
  output$moduleSelection_cfu <- renderUI({
    # allow the user to manually enter some specific new input variables depending on the modules selected

      if( substr(input$Modules, 1,4) == "Proc" |substr(input$Modules, 1,4) == "Post"|substr(input$Modules, 1,4) == "Home" ){
        
        tagList(
          #manually enter values to be used as input for the processing module
          
          #select proba distribution to be used for CFU
          selectInput(inputId="ProbaDistrib_cfu", label="Select probability distribution - CFU:", choices=c("Point estimate", 
                                                                                                         "Uniform", 
                                                                                                         "Triangular", 
                                                                                                         "Pert",
                                                                                                         "Normal",
                                                                                                         "Beta",
                                                                                                         "Poisson",
                                                                                                         "Negbin",
                                                                                                         "Binomial",
                                                                                                         "Laplace",
                                                                                                         "Lognormal",
                                                                                                         "LogLogistic",
                                                                                                         "Shifted LogLogistic",
                                                                                                         "Gamma")
          )
        )
      }
    
  })
  
  output$moduleSelection_prev <- renderUI({
    # allow the user to manually enter some specific new input variables depending on the modules selected
      if(substr(input$Modules, 1,4) == "Proc" |substr(input$Modules, 1,4) == "Post"|substr(input$Modules, 1,4) == "Home" ){
        
        tagList(
          #manually enter values to be used as input for the processing module
          
          #select proba distribution to be used for prev
          selectInput(inputId="ProbaDistrib_prev", label="Select probability distribution - Prevalence contaminated products:", choices=c("Point estimate", 
                                                                                                                 "Uniform", 
                                                                                                                 "Triangular", 
                                                                                                                 "Pert",
                                                                                                                 "Normal",
                                                                                                                 "Beta",
                                                                                                                 "Poisson",
                                                                                                                 "Negbin",
                                                                                                                 "Binomial",
                                                                                                                 "Laplace",
                                                                                                                 "Lognormal",
                                                                                                                 "LogLogistic",
                                                                                                                 "Shifted LogLogistic",
                                                                                                                 "Gamma")
          )
        )
      }
    
  })
  
  output$distribSelection_cfu <- renderUI({
    # allow the user to manually enter some specific new input variables depending on the modules selected

      if(substr(input$Modules, 1,4) == "Proc" |substr(input$Modules, 1,4) == "Post"|substr(input$Modules, 1,4) == "Home" ){
        
        if(input$ProbaDistrib_cfu == "Point estimate"){
          tagList(
            numericInput(inputId="Other_cfu", label="Other:", value=0, min=0)
          )
          
        } else if (input$ProbaDistrib_cfu == "Uniform"){
          tagList(
            numericInput(inputId="Min_cfu", label="Minimum:", value=0, min=0),
            numericInput(inputId="Max_cfu", label="Maximum:", value=0)
          )
          
        } else if (input$ProbaDistrib_cfu == "Triangular" | input$ProbaDistrib_cfu == "Pert"){
          tagList(
            numericInput(inputId="Min_cfu", label="Minimum:", value=0),
            numericInput(inputId="Max_cfu", label="Maximum:", value=0),
            numericInput(inputId="Mean_Mode_cfu", label="Mode:", value=0)
          )
          
        } else if (input$ProbaDistrib_cfu == "Normal" | input$ProbaDistrib_cfu == "Lognormal"){
          tagList(
            numericInput(inputId="Mean_Mode_cfu", label="Mean_Mode:", value=0),
            numericInput(inputId="SD_cfu", label="standard deviation:", value=0)
          )
          
        } else if (input$ProbaDistrib_cfu == "Poisson" | input$ProbaDistrib_cfu == "Binomial"){
          tagList(
            numericInput(inputId="Other_cfu", label="Other:", value=0)
          )
          
        } else if (input$ProbaDistrib_cfu == "Beta" | input$ProbaDistrib_cfu == "LogLogistic" | input$ProbaDistrib_cfu == "Gamma"){
          tagList(
            numericInput(inputId="Other_cfu", label="Other:", value=0),
            numericInput(inputId="Other2_cfu", label="Other2:", value=0)
          )
          
        } else if (input$ProbaDistrib_cfu == "Negbin" | input$ProbaDistrib_cfu == "Laplace"){
          tagList(
            numericInput(inputId="Other_cfu", label="Other:", value=0),
            numericInput(inputId="Mean_Mode_cfu", label="Mean_Mode:", value=0)
          )
          
        } else if (input$ProbaDistrib_cfu == "Shifted LogLogistic"){
          tagList(
            numericInput(inputId="Other_cfu", label="Other:", value=0),
            numericInput(inputId="Other2_cfu", label="Other2:", value=0),
            numericInput(inputId="Other3_cfu", label="Other3:", value=0)
          )
        }
      
    }
        
    
  })
  
  output$distribSelection_prev <- renderUI({

      if(substr(input$Modules, 1,4) == "Proc" |substr(input$Modules, 1,4) == "Post"|substr(input$Modules, 1,4) == "Home" ){
        if(input$ProbaDistrib_prev == "Point estimate"){
          tagList(
            numericInput(inputId="Other_prev", label="Other:", value=0, min=0, max=1)
          )
          
        } else if (input$ProbaDistrib_prev == "Uniform"){
          tagList(
            numericInput(inputId="Min_prev", label="Minimum:", value=0, min=0),
            numericInput(inputId="Max_prev", label="Maximum:", value=0, min=1)
          )
          
        } else if (input$ProbaDistrib_prev == "Triangular" | input$ProbaDistrib_prev == "Pert"){
          tagList(
            numericInput(inputId="Min_prev", label="Minimum:", value=0),
            numericInput(inputId="Max_prev", label="Maximum:", value=0),
            numericInput(inputId="Mean_Mode_prev", label="Mode:", value=0)
          )
          
        } else if (input$ProbaDistrib_prev == "Normal" | input$ProbaDistrib_prev == "Lognormal"){
          tagList(
            numericInput(inputId="Mean_Mode_prev", label="Mean_Mode:", value=0),
            numericInput(inputId="SD_prev", label="standard deviation:", value=0)
          )
          
        } else if (input$ProbaDistrib_prev == "Poisson" | input$ProbaDistrib_prev == "Binomial"){
          tagList(
            numericInput(inputId="Other_prev", label="Other:", value=0)
          )
          
        } else if (input$ProbaDistrib_prev == "Beta" | input$ProbaDistrib_prev == "LogLogistic" | input$ProbaDistrib_prev == "Gamma"){
          tagList(
            numericInput(inputId="Other_prev", label="Other:", value=0),
            numericInput(inputId="Other2_prev", label="Other2:", value=0)
          )
          
        } else if (input$ProbaDistrib_prev == "Negbin" | input$ProbaDistrib_prev == "Laplace"){
          tagList(
            numericInput(inputId="Other_prev", label="Other:", value=0),
            numericInput(inputId="Mean_Mode_prev", label="Mean_Mode:", value=0)
          )
          
        } else if (input$ProbaDistrib_prev == "Shifted LogLogistic"){
          tagList(
            numericInput(inputId="Other_prev", label="Other:", value=0),
            numericInput(inputId="Other2_prev", label="Other2:", value=0),
            numericInput(inputId="Other3_prev", label="Other3:", value=0)
          )
        }
      
    }
    
    
  }) 

  
  
  # SIMULATION TAB --------------------------------------------------------------------------------------------------------------------------
  
  simulatedVariables <- eventReactive(input$buttonSimulation, {
  #simulated data based on the values of the imported file
    validate(
      need(input$estimatedVariables!="","Please upload data before running simulation")
    )
    
    #read input file
    req(input$estimatedVariables)
    df <- read_excel(input$estimatedVariables$datapath)
    n<- nrow(df)
    
    if (substr(input$Modules, 1,4) != "Prod" ){
      if(substr(input$Modules, 1,4) == "Proc" ){
        df[n+1,] <- NA
        df[n+2,] <- NA
        df$Variable[n+1] <- "C_prod"
        df$Distribution[n+1] <- as.character(input$ProbaDistrib_cfu)
        df$Variable[n+2] <- "Prev_prod"
        df$Distribution[n+2] <- as.character(input$ProbaDistrib_prev)
      } else if (substr(input$Modules, 1,4) == "Post" ) {
        df[n+1,] <- NA
        df[n+2,] <- NA
        df$Variable[n+1] <- "C_proc"
        df$Distribution[n+1] <- input$ProbaDistrib_cfu
        df$Variable[n+2] <- "Prev_proc"
        df$Distribution[n+2] <- input$ProbaDistrib_prev
      } else if (substr(input$Modules, 1,4) == "Home" ) {
        df[n+1,] <- NA
        df[n+2,] <- NA
        df$Variable[n+1] <- "C_pproc"
        df$Distribution[n+1] <- input$ProbaDistrib_cfu
        df$Variable[n+2] <- "Prev_pproc"
        df$Distribution[n+2] <- input$ProbaDistrib_prev
      }
      
      if(input$ProbaDistrib_cfu == "Point estimate"){
        df$Other[n+1] <- input$Other_cfu
      } else if (input$ProbaDistrib_cfu == "Uniform"){
        df$Min[n+1] <- input$Min_cfu
        df$Max[n+1] <- input$Max_cfu
      } else if (input$ProbaDistrib_cfu == "Triangular" | input$ProbaDistrib_cfu == "Pert"){
        df$Min[n+1] <- input$Min_cfu
        df$Max[n+1] <- input$Max_cfu
        df$Mean_Mode[n+1] <- input$Mean_Mode_cfu
      } else if (input$ProbaDistrib_cfu == "Normal" | input$ProbaDistrib_cfu == "Lognormal"){
        df$Mean_Mode[n+1] <- input$Mean_Mode_cfu
        df$SD[n+1] <- input$SD_cfu
      } else if (input$ProbaDistrib_cfu == "Poisson" | input$ProbaDistrib_cfu == "Binomial"){
        df$Other[n+1] <- input$Other_cfu
      } else if (input$ProbaDistrib_cfu == "Beta" | input$ProbaDistrib_cfu == "LogLogistic" | input$ProbaDistrib_cfu == "Gamma"){
        df$Other[n+1] <- input$Other_cfu
        df$Other2[n+1] <- input$Other2_cfu
      } else if (input$ProbaDistrib_cfu == "Negbin" | input$ProbaDistrib_cfu == "Laplace"){
        df$Other[n+1] <- input$Other_cfu
        df$Mean_Mode[n+1] <- input$Mean_Mode_cfu
      } else if (input$ProbaDistrib_cfu == "Shifted LogLogistic"){
        df$Other[n+1] <- input$Other_cfu
        df$Other2[n+1] <- input$Other2_cfu
        df$Other3[n+1] <- input$Other3_cfu
      }
      
      if(input$ProbaDistrib_prev == "Point estimate"){
        df$Other[n+2] <- input$Other_prev
      } else if (input$ProbaDistrib_prev == "Uniform"){
        df$Min[n+2] <- input$Min_prev
        df$Max[n+2] <- input$Max_prev
      } else if (input$ProbaDistrib_prev == "Triangular" | input$ProbaDistrib_prev == "Pert"){
        df$Min[n+2] <- input$Min_prev
        df$Max[n+2] <- input$Max_prev
        df$Mean_Mode[n+2] <- input$Mean_Mode_prev
      } else if (input$ProbaDistrib_prev == "Normal" | input$ProbaDistrib_prev == "Lognormal"){
        df$Mean_Mode[n+2] <- input$Mean_Mode_prev
        df$SD[n+2] <- input$SD_prev
      } else if (input$ProbaDistrib_prev == "Poisson" | input$ProbaDistrib_prev == "Binomial"){
        df$Other[n+2] <- input$Other_prev
      } else if (input$ProbaDistrib_prev == "Beta" | input$ProbaDistrib_prev == "LogLogistic" | input$ProbaDistrib_prev == "Gamma"){
        df$Other[n+2] <- input$Other_prev
        df$Other2[n+2] <- input$Other2_prev
      } else if (input$ProbaDistrib_prev == "Negbin" | input$ProbaDistrib_prev == "Laplace"){
        df$Other[n+2] <- input$Other_prev
        df$Mean_Mode[n+2] <- input$Mean_Mode_prev
      } else if (input$ProbaDistrib_prev == "Shifted LogLogistic"){
        df$Other[n+2] <- input$Other_prev
        df$Other2[n+2] <- input$Other2_prev
        df$Other3[n+2] <- input$Other3_prev
      }
    }
    
        
    #prepare output file
    namesData<-c(
      #Case study
      "Product", "Bacteria", "Gene"
    )
    data <- as.data.frame(matrix(0, nrow= input$Runs, ncol= length(namesData)))
    colnames(data)<- namesData
    data$Product <- input$Product
    data$Bacteria <- input$Bacteria
    data$Gene <- input$Gene
    data$Farm_type <- input$Farm_type
    data$Product_cut <- input$Product_cut
    data$Pack_type <- input$Pack_type
    
    if(input$Product == "Chicken"){
      data$Scalding_type <- input$Scalding_type
      data$Meat_skin <-input$Meat_skin
      data$B_flock_status <- "p"
    }else if(input$Product == "Lettuce"){
      data$Product_wash <- input$Product_wash
    }
    
    #perform simulations
    dataSimulation(data, df, N= input$Runs)

  })
  
  output$moduleSelection_Simulation <- renderUI({
  # display module to be visualized once the a button has been activated
    req(simulatedVariables())
    selectInput(inputId="Module_Simulation", label="Select the module to be investigated", 
                choices= if(substr(input$Modules, 1,4) == "Proc"){
                  c("Processing", "Post-processing", "Home-preparation")
                } else if (substr(input$Modules, 1,4) == "Post"){
                  c("Post-processing", "Home preparation")
                } else if (substr(input$Modules, 1,4) == "Home"){
                  c("Home-preparation")
                }else{
                  c("Production","Processing", "Post-processing", "Home-preparation")
                }
                )
    
  })
  
  output$simulatedVariablesDescription <- renderTable({ 
  #display a table with variables description
    req(input$estimatedVariables)
    req(input$Module_Simulation)
    read_excel(input$estimatedVariables$datapath)%>%
      filter(Module == input$Module_Simulation) %>%
      mutate(Min = ifelse(!is.na(Min), paste0("Min:", Min), ""))%>%
      mutate(Max = ifelse(!is.na(Max), paste0("Max:", Max), ""))%>%
      mutate(Mean = ifelse(!is.na(Mean_Mode), paste0("Mean or Mode:", Mean_Mode), ""))%>%
      mutate(SD = ifelse(!is.na(SD), paste0("sd:", SD), ""))%>%
      mutate(Other = ifelse(is.na(Other)&is.na(Other2)&is.na(Other3), "",
                            ifelse(!is.na(Other)&is.na(Other2),  paste("Other: ", Other, sep=""), 
                                   ifelse(!is.na(Other)& !is.na(Other2) & is.na(Other3), paste("Other: ", Other, ", ", Other2, sep=""),
                                          ifelse(!is.na(Other)& !is.na(Other2) & !is.na(Other3), paste("Other: ", Other,", ", Other2,", ", Other3, sep=""), "")
                                          )
                                   )
                            )
             )%>%
      mutate(Parameter = paste(Min, Max, Mean, SD, Other, sep=" "))%>%
      select(Variable, Description, Units, Distribution, Truncated, Parameter)
      

  })
  
  output$plotSimulation <- renderPlot({ 
  #plot of the simulated estimated variables
    
    req(simulatedVariables())
    req(input$estimatedVariables)
    req(input$Module_Simulation)
    
    df <- read_excel(input$estimatedVariables$datapath)%>%
      select(Module, Variable, Description, Units) %>%
      filter(Module == input$Module_Simulation) 
    
    if(substr(input$Modules, 1,4) == "Proc" ){
      data<- simulatedVariables() %>%
        select(C_prod, Prev_prod, df$Variable)
    } else if (substr(input$Modules, 1,4) == "Post" ) {
      data<- simulatedVariables() %>%
        select(C_proc, Prev_proc, df$Variable)
    } else if (substr(input$Modules, 1,4) == "Home" ) {
      data<- simulatedVariables() %>%
        select(C_pproc, Prev_pproc, df$Variable)
    } else {
      data<- simulatedVariables() %>%
        select(df$Variable)
    }

    data<- melt(data) 
    p<- data %>%
      ggplot(aes(value))+
      geom_density(size=2)+
      labs(y = "Density") +
      facet_wrap(~ variable, scales = "free")+ 
      theme(axis.text.x = element_text(size=12),
            axis.text.y = element_text(size=12),
            axis.title.x = element_text(face="bold", size=14),
            axis.title.y = element_text(face="bold", size=14),
            strip.text = element_text(face="bold",size = 16))+theme_bw()
      #+ theme_bw(panel.spacing = unit(0.0000000005, "lines"))
    vals$p0 <- p
    p

  })
  
  output$downloadPlot0 <- downloadHandler( 
  #download plot 1/2
    filename = function(){paste('simulationPlot', input$Module_Simulation,'.png', sep = '')},
    content = function(file){
      ggsave(file,vals$p0,
             width = 30, height = 30, dpi = 150, units = "cm")
    })
  output$get_plotSimulation <- renderUI({ 
  #download plot 2/2
    req(simulatedVariables())
    downloadButton("downloadPlot0", "Download Plot simulation") 
    
  })
  


  
  # RISK ASSESSMENT TAB --------------------------------------------------------------------------------------------------------------------------
  
  calculatedVariables <- eventReactive(input$buttonRiskAssessment, {
  #risk assessement based on data simulated in the previous page
    validate(
      need(input$Module_Simulation !="" ,"Please simulate data before running calculation")
    )
    
    #read input file
    req(simulatedVariables())
    data <- simulatedVariables()
    
    #run modules
    if( substr(input$Modules, 1,4) == "Proc" ){
      source(paste0("www/","Module_processingShiny_", input$Product, ".R"), local=TRUE)
      source(paste0("www/","Module_postprocessingShiny_", input$Product, ".R"), local=TRUE)
      source(paste0("www/","Module_homepreparationShiny_", input$Product, ".R"), local=TRUE)
      
    } else if (substr(input$Modules, 1,4) == "Post" ) {
      if(input$Product == "Lettuce" ){
        if(input$Product_cut == "yes"){
          data$Size <- data$Size_bag
        }else{
          data$Size <- data$Size_mean
        }
      }
      source(paste0("www/","Module_postprocessingShiny_", input$Product, ".R"), local=TRUE)
      source(paste0("www/","Module_homepreparationShiny_", input$Product, ".R"), local=TRUE)
      
    } else if (substr(input$Modules, 1,4) == "Home" ) {
      if(input$Product == "Lettuce" ){
        if(input$Product_cut == "yes"){
          data$Size <- data$Size_bag
        }else{
          data$Size <- data$Size_mean
        }
      }
      source(paste0("www/","Module_homepreparationShiny_", input$Product, ".R"), local=TRUE)
      
    } else {
      source(paste0("www/","Module_productionShiny_", input$Product, ".R"), local=TRUE)
      source(paste0("www/","Module_processingShiny_", input$Product, ".R"), local=TRUE)
      source(paste0("www/","Module_postprocessingShiny_", input$Product, ".R"), local=TRUE)
      source(paste0("www/","Module_homepreparationShiny_", input$Product, ".R"), local=TRUE)
    }
    
    vals$rawData<- data
    data
    
  })
  
  output$foodItem_description <- renderText({
  # describe the food item considered in the analysis based on the value of the selected and estimated variables
    if (input$Product_cut == "yes"){
      A <- "portioned "
    } else {
      A <- "whole "
    }
    
    if(input$Product == "Lettuce" ){
      
      B <- calculatedVariables() %>% summarize(mean(Size))
      if(input$Product_cut == "yes"){
        A<- "bagged "
      } 
        
      S <- calculatedVariables() %>% summarize(mean(Serv))
      paste("The food item considered in the post-processing and home-preparation module is a " , "<B>", A, input$Product, "</B>", 
            ". The average Size of this food item is ", "<B>", round(B, 1) , " g. ", "</B>",
            "The average Size of serving of this food item is ", "<B>", round(S, 1) , " g.", "</B>", sep="")
      
    }else{
      B <- calculatedVariables() %>% summarize(mean(Size))
      paste("The food item considered in the post-processing and home-preparation module is a " , "<B>", A, input$Product, "</B>", ". The average Size of this food item is ", "<B>", round(B, 1) , " g.", "</B>", sep="")
      
    }
    
  })
  

  data_overallRisk <- reactive({ 
  #create summary table 
  
    #run modules
    if(input$Product == "Chicken"){
      if(substr(input$Modules, 1,4) == "Proc" ){
        outputVar <-c("Prev_proc","C_proc",
                      "Prev_pproc","C_pproc",
                      "Prev_home_cook","C_home_cook", "P_home_cc","C_home_cc")
        outputTab <- outputTab_chicken %>% 
          filter(variable != "C_prod" & variable != "Prev_prod")
        
      } else if (substr(input$Modules, 1,4) == "Post" ) {
        outputVar <-c("Prev_pproc","C_pproc",
                      "Prev_home_cook","C_home_cook", "P_home_cc","C_home_cc")
        outputTab <- outputTab_chicken %>% 
          filter(variable != "C_prod" & variable != "Prev_prod" & variable != "C_proc"& variable != "Prev_proc")
        
      } else if (substr(input$Modules, 1,4) == "Home" ) {
        outputVar <-c("Prev_home_cook","C_home_cook", "P_home_cc","C_home_cc")
        outputTab <- outputTab_chicken %>% 
          filter(variable != "C_prod" & variable != "Prev_prod" & variable != "C_proc"& variable != "Prev_proc"& variable != "C_pproc"& variable != "Prev_pproc")
        
      } else {
        outputVar <- outputVar_chicken
        outputTab <- outputTab_chicken
      }
     
    } else if(input$Product == "Lettuce"){
      if(substr(input$Modules, 1,4) == "Proc" ){
        outputVar <-c("Prev_proc","C_proc",
                      "Prev_pproc","C_pproc",
                      "Prev_home_cook","C_home_cook")
        outputTab <- outputTab_lettuce %>% 
          filter(variable != "C_prod" & variable != "Prev_prod")
        
      } else if (substr(input$Modules, 1,4) == "Post" ) {
        outputVar <-c("Prev_pproc","C_pproc",
                      "Prev_home_cook","C_home_cook")
        outputTab <- outputTab_lettuce %>% 
          filter(variable != "C_prod" & variable != "Prev_prod" & variable != "C_proc"& variable != "Prev_proc")
        
      } else if (substr(input$Modules, 1,4) == "Home" ) {
        outputVar <-c("Prev_home_cook","C_home_cook")
        outputTab <- outputTab_lettuce %>% 
          filter(variable != "C_prod" & variable != "Prev_prod" & variable != "C_proc"& variable != "Prev_proc"& variable != "C_pproc"& variable != "Prev_pproc")
        
      } else {
        outputVar <- outputVar_lettuce
        outputTab <- outputTab_lettuce
      }
    }
    
    
    subRA_overall0<- calculatedVariables()%>%
      select(all_of(outputVar))
      subRA_overall<- melt(subRA_overall0)
      
      subRA_overall_raw<- subRA_overall %>% 
        group_by(variable) %>% 
        summarize(Mean = mean(value), Median =median(value), Percentile_low = quantile(value, probs=c(input$centile[1])), Percentile_high = quantile(value, probs=c(input$centile[2])))
      
      if(substr(input$Modules, 1,4) == "Prod" ){ 
        
      subRA_overall_lowOut1<- subRA_overall0 %>% 
        mutate(C_prod = ifelse(C_prod >1, C_prod, 0))%>%
        mutate(Prev_prod = ifelse(C_prod ==0 , 0, Prev_prod))
      
      subRA_overall_lowOut1<- melt(subRA_overall_lowOut1)%>%
        filter(variable == "C_prod" | variable == "Prev_prod" )%>%
        group_by(variable) %>% 
        summarize(Mean_adjusted = mean(value), Median_adjusted=median(value), Percentile_adj_low = quantile(value, probs=c(input$centile[1])), Percentile_adj_high = quantile(value, probs=c(input$centile[2])))
      
      subRA_overall_lowOut2<- subRA_overall0 %>% 
        mutate(C_proc = ifelse(C_proc >1, C_proc, 0))%>%
        mutate(Prev_proc = ifelse(C_proc ==0 , 0, Prev_proc))
      
      subRA_overall_lowOut2<- melt(subRA_overall_lowOut2)%>%
        filter(variable == "C_proc" | variable == "Prev_proc" )%>%
        group_by(variable) %>% 
        summarize(Mean_adjusted = mean(value), Median_adjusted=median(value), Percentile_adj_low = quantile(value, probs=c(input$centile[1])), Percentile_adj_high = quantile(value, probs=c(input$centile[2])))
      
      subRA_overall_lowOut <- rbind(subRA_overall_lowOut1, subRA_overall_lowOut2)
      
      subRA_overall <- merge(subRA_overall_raw, subRA_overall_lowOut, by="variable", all.x=T)
      subRA_overall<- merge(subRA_overall, outputTab, all.y=T)%>%
        select(Module, variable, Mean, Median,Percentile_low, Percentile_high, Mean_adjusted, Median_adjusted, Percentile_adj_low, Percentile_adj_high)
      subRA_overall[order(subRA_overall$Module),]
      
      } else if (substr(input$Modules, 1,4) == "Proc" ){
        
        subRA_overall_lowOut2<- subRA_overall0 %>% 
          mutate(C_proc = ifelse(C_proc >1, C_proc, 0))%>%
          mutate(Prev_proc = ifelse(C_proc ==0 , 0, Prev_proc))
        
        subRA_overall_lowOut2<- melt(subRA_overall_lowOut2)%>%
          filter(variable == "C_proc" | variable == "Prev_proc" )%>%
          group_by(variable) %>% 
          summarize(Mean_adjusted = mean(value), Median_adjusted=median(value), Percentile_adj_low = quantile(value, probs=c(input$centile[1])), Percentile_adj_high = quantile(value, probs=c(input$centile[2])))
        
        subRA_overall_lowOut <- subRA_overall_lowOut2
        
        subRA_overall <- merge(subRA_overall_raw, subRA_overall_lowOut, by="variable", all.x=T)
        subRA_overall<- merge(subRA_overall, outputTab, all.y=T)%>%
          select(Module, variable, Mean, Median,Percentile_low, Percentile_high, Mean_adjusted, Median_adjusted, Percentile_adj_low, Percentile_adj_high)
        subRA_overall[order(subRA_overall$Module),]
        
      } else {
        
        subRA_overall <-subRA_overall_raw
        subRA_overall<- merge(subRA_overall, outputTab, all.y=T)%>%
          select(Module, variable, Mean, Median,Percentile_low, Percentile_high)
        subRA_overall[order(subRA_overall$Module),]
        
      }
      
  })
  
  output$overallRisk <- renderTable({ 
    #plot table overall risk
    data_overallRisk()
  }, caption = paste("Overall risk"),
  caption.placement = getOption("xtable.caption.placement", "top"),
  caption.width = getOption("xtable.caption.width", NULL))
  
  output$download_overallRisk <- downloadHandler( 
    #download table 2/3
    filename = function(){paste0("overallResults", input$Product, "_",input$Runs, "simulation.csv", sep="")}, 
    content = function(file){
      write.csv(data_overallRisk() , file)
    }
  )
  
  output$get_overallRisk <- renderUI({ 
    #download table 3/3
    req(calculatedVariables())
    downloadButton('download_overallRisk',"Download the table") })
  
  
  data_specificRisk <- reactive({ 
    #create summary table per subgroup (for chicken only and only when production module is included)
    
    #run modules
    outputVar <- outputVar_chicken
    outputTab <- outputTab_chicken
   
    if(substr(input$Modules, 1,4) == "Prod") {
      
      subRA_overall0<- calculatedVariables()%>%
        select(all_of(outputVar), B_flock_status)%>%
        mutate( B_flock_status =ifelse( B_flock_status =="p","Positive","Negative"))
      subRA_overall<- melt(subRA_overall0, id.vars="B_flock_status")
      
      subRA_overall_raw<- subRA_overall %>% 
        group_by(variable, B_flock_status) %>% 
        summarize(Mean = mean(value), Median =median(value), Percentile_low = quantile(value, probs=c(input$centile[1])), Percentile_high = quantile(value, probs=c(input$centile[2])))
      
      subRA_overall_lowOut1<- subRA_overall0 %>% 
        mutate(C_prod = ifelse(C_prod >1, C_prod, 0))%>%
        mutate(Prev_prod = ifelse(C_prod ==0 , 0, Prev_prod))
      subRA_overall_lowOut1<- melt(subRA_overall_lowOut1 , id.vars="B_flock_status")%>%
        filter(variable == "C_prod" | variable == "Prev_prod" )%>%
        group_by(variable, B_flock_status) %>% 
        summarize(Mean_adjusted = mean(value), Median_adjusted=median(value), Percentile_adj_low = quantile(value, probs=c(input$centile[1])), Percentile_adj_high = quantile(value, probs=c(input$centile[2])))
      
      subRA_overall_lowOut2<- subRA_overall0 %>% 
        mutate(C_proc = ifelse(C_proc >1, C_proc, 0))%>%
        mutate(Prev_proc = ifelse(C_proc ==0 , 0, Prev_proc))
      subRA_overall_lowOut2<- melt(subRA_overall_lowOut2, id.vars="B_flock_status")%>%
        filter(variable == "C_proc" | variable == "Prev_proc" )%>%
        group_by(variable, B_flock_status) %>% 
        summarize(Mean_adjusted = mean(value), Median_adjusted=median(value), Percentile_adj_low = quantile(value, probs=c(input$centile[1])), Percentile_adj_high = quantile(value, probs=c(input$centile[2])))
      
      subRA_overall_lowOut <- rbind(subRA_overall_lowOut1, subRA_overall_lowOut2)
      
      subRA_overall <- merge(subRA_overall_raw, subRA_overall_lowOut, by=c("variable", "B_flock_status"), all.x=T)
      subRA_overall<- merge(subRA_overall, outputTab, all.y=T)%>%
        rename(Flock_status = B_flock_status)%>%
        select(Module, variable,Flock_status, Mean, Median,Percentile_low, Percentile_high, Mean_adjusted, Median_adjusted, Percentile_adj_low, Percentile_adj_high)
      subRA_overall[order(subRA_overall$Module),]
      
    }
  
    
  })
  
  output$specificRisk <- renderTable({ 
    #plot table overall risk
    data_specificRisk()
  }, caption = paste("Risk per sub group (positive vs negative farms)"),
  caption.placement = getOption("xtable.caption.placement", "top"),
  caption.width = getOption("xtable.caption.width", NULL))
  
  output$download_specificRisk <- downloadHandler( 
    #download table 2/3
    filename = function(){paste0("overallResults", input$Product, "_",input$Runs, "simulation.csv", sep="")}, 
    content = function(file){
      write.csv(data_specificRisk() , file)
    }
  )
  output$get_specificRisk <- renderUI({ 
    #download table 3/3
    req(calculatedVariables())
    if(input$Product == "Chicken" &  substr(input$Modules, 1,4) == "Prod") {
      downloadButton('download_specificRisk',"Download the table per group")
    }
    })
  
  
  output$get_rawData <- renderUI({ 
  #download raw data 1/2
    req(calculatedVariables())
    downloadButton('download_rawData',"Download the raw data") })
  output$download_rawData <- downloadHandler( 
  #download raw data 2/2
    filename = function(){paste0("rawResults", input$Product, "_",input$Runs, "simulation.csv", sep="")}, 
    content = function(file){
      write.csv(vals$rawData , file)
    }
  )
 
  
  output$moduleSelection_Risk <- renderUI({
  # display module to be visualized once the button has been activated
    req(calculatedVariables())
    selectInput(inputId="Module_Risk", label="Select the module for which you want to visualize the model outputs", 
                choices= if(substr(input$Modules, 1,4) == "Proc"){
                  c("Processing", "Post-processing", "Home-preparation")
                } else if (substr(input$Modules, 1,4) == "Post"){
                  c("Post-processing", "Home-preparation")
                } else if (substr(input$Modules, 1,4) == "Home"){
                  c("Home-preparation")
                }else{
                  c("Production","Processing", "Post-processing", "Home-preparation")
                }
    )
    
  })
  
  output$outcomeDistribution <- renderPlot({ 
  #Create plot of the overall probability distribution of the selected module outcome
    req(calculatedVariables())
    req(input$Module_Risk)
    
    if(input$Product == "Chicken"){
      if(substr(input$Modules, 1,4) == "Proc" ){
        outputVar <-c("Prev_proc","C_proc",
                      "Prev_pproc","C_pproc",
                      "Prev_home_cook","C_home_cook", "P_home_cc","C_home_cc")
        outputTab <- outputTab_chicken %>% 
          filter(variable != "C_prod" & variable != "Prev_prod")
        
      } else if (substr(input$Modules, 1,4) == "Post" ) {
        outputVar <-c("Prev_pproc","C_pproc",
                      "Prev_home_cook","C_home_cook", "P_home_cc","C_home_cc")
        outputTab <- outputTab_chicken %>% 
          filter(variable != "C_prod" & variable != "Prev_prod" & variable != "C_proc"& variable != "Prev_proc")
        
      } else if (substr(input$Modules, 1,4) == "Home" ) {
        outputVar <-c("Prev_home_cook","C_home_cook", "P_home_cc","C_home_cc")
        outputTab <- outputTab_chicken %>% 
          filter(variable != "C_prod" & variable != "Prev_prod" & variable != "C_proc"& variable != "Prev_proc"& variable != "C_pproc"& variable != "Prev_pproc")
        
      } else {
        outputVar <- outputVar_chicken
        outputTab <- outputTab_chicken
      }
      
    } else if(input$Product == "Lettuce"){
      if(substr(input$Modules, 1,4) == "Proc" ){
        outputVar <-c("Prev_proc","C_proc",
                      "Prev_pproc","C_pproc",
                      "Prev_home_cook","C_home_cook")
        outputTab <- outputTab_lettuce %>% 
          filter(variable != "C_prod" & variable != "Prev_prod")
        
      } else if (substr(input$Modules, 1,4) == "Post" ) {
        outputVar <-c("Prev_pproc","C_pproc",
                      "Prev_home_cook","C_home_cook")
        outputTab <- outputTab_lettuce %>% 
          filter(variable != "C_prod" & variable != "Prev_prod" & variable != "C_proc"& variable != "Prev_proc")
        
      } else if (substr(input$Modules, 1,4) == "Home" ) {
        outputVar <-c("Prev_home_cook","C_home_cook")
        outputTab <- outputTab_lettuce %>% 
          filter(variable != "C_prod" & variable != "Prev_prod" & variable != "C_proc"& variable != "Prev_proc"& variable != "C_pproc"& variable != "Prev_pproc")
        
      } else {
        outputVar <- outputVar_lettuce
        outputTab <- outputTab_lettuce
      }
    }
    
    subset <- outputTab %>%
      filter(Module == input$Module_Risk)
    COLOR <- ifelse( input$Module_Risk=="Home-preparation", "darkorange",
                     ifelse(input$Module_Risk=="Production", "blue",
                            ifelse(input$Module_Risk=="Processing", "darkgreen", "black")))
    subRA_overall<- calculatedVariables() %>%
      select(contains(subset$variable))
    subRA_overall<- melt(subRA_overall)
    subRA_overall<- subRA_overall %>% 
      group_by(variable) %>% 
      mutate(mean = mean(value), median=median(value)) %>% 
      ungroup()
    
    cent_low_prev<- quantile(subRA_overall$value[which(substr(subRA_overall$variable, 1,4) == "Prev" )], probs=c(input$centile2[1]))
    cent_up_prev<- quantile(subRA_overall$value[which(substr(subRA_overall$variable, 1,4) == "Prev")], probs=c(input$centile2[2]))
    
    p1<- subRA_overall%>%
      filter(substr(variable, 1,4) == "Prev" )%>%
      ggplot(aes(value)) +
      geom_density(fill = COLOR , 
                   alpha = .3, col = NA) +
      geom_vline(aes(xintercept = mean, col = "Mean", linetype="Mean")) +
      geom_vline(aes(xintercept = median, col = "Median", linetype="Median")) +
      labs(y = "Probability density") +
      scale_x_continuous( limits = c(cent_low_prev, cent_up_prev)) +
      scale_color_manual(name = "Statistics", values = c(Median = "black", Mean = "black"))+
      scale_linetype_manual(name = "Statistics", values= c(Median = "dashed", Mean = "dotted"))+
      theme_bw()%+replace%
      theme(legend.position = "bottom")+
      ggtitle("Overall Prevalence of contaminated products")+ 
      theme(axis.text.x = element_text(size=12),
            axis.text.y = element_text(size=12),
            axis.title.x = element_text(face="bold", size=14),
            axis.title.y = element_text(face="bold", size=14),
            strip.text = element_text(face="bold",size = 16),
            legend.text=element_text(size=12))
    
    cent_low_C<- quantile(subRA_overall$value[which(substr(subRA_overall$variable, 1,2) == "C_" & subRA_overall$variable !="C_prod_n")], probs=c(input$centile2[1]))
    cent_up_C<- quantile(subRA_overall$value[which(substr(subRA_overall$variable, 1,2) == "C_" & subRA_overall$variable !="C_prod_n")], probs=c(input$centile2[2]))
      
    p2<- subRA_overall%>%
      filter(substr(variable, 1,2) == "C_" & variable !="C_prod_n")%>%
      ggplot(aes(value)) +
      geom_density(fill = COLOR , 
                   alpha = .3, col = NA) +
      geom_vline(aes(xintercept = mean, col = "Mean", linetype="Mean")) +
      geom_vline(aes(xintercept = median, col = "Median", linetype="Median")) +
      labs(y = "Probability density") +
      scale_x_continuous(limits = c(cent_low_C,cent_up_C)) +
      scale_color_manual(name = "Statistics", values = c(Median = "black", Mean = "black"))+
      scale_linetype_manual(name = "Statistics", values= c(Median = "dashed", Mean = "dotted"))+
      theme_bw()%+replace%
      theme(legend.position = "bottom")+
      ggtitle("Overall bacteria contamination (CFU)")+ 
      theme(axis.text.x = element_text(size=12),
            axis.text.y = element_text(size=12),
            axis.title.x = element_text(face="bold", size=14),
            axis.title.y = element_text(face="bold", size=14),
            strip.text = element_text(face="bold",size = 16),
            legend.text=element_text(size=12))
    
    p<- grid.arrange(p1, p2, ncol=2)
    vals$p1 <- p
    p
    
  })
  
  output$downloadPlot1 <- downloadHandler(
  #download plot 1/2
    filename = function(){paste('overallQAplot', input$Module_Risk,'.png', sep = '')},
    content = function(file){
      ggsave(file,vals$p1,
             width = 30, height = 12, dpi = 150, units = "cm")
    })
  output$get_plotRisk1 <- renderUI({
  #download plot 2/2
    req(calculatedVariables())
    downloadButton("downloadPlot1", "Download Plot overall risk") })
  
  
  output$outcomeDistributionFlock <- renderPlot({
  #Create plot of risk estimate depending on the origin of the flock - only for chicken
    req(calculatedVariables())
    req(input$Module_Risk)
    
    outputVar <- outputVar_chicken
    outputTab <- outputTab_chicken
    
    data<-calculatedVariables()
    
    if(length(unique(data$B_flock_status)) !=1) {
      
      subset <- outputTab %>%
        filter(Module == input$Module_Risk)
      subRA_overall<-data %>%
        select(contains(subset$variable), B_flock_status)
      
      subRA_overall<- melt(subRA_overall, id="B_flock_status")
      subRA_overall<- subRA_overall %>% 
        group_by(variable, B_flock_status) %>% 
        mutate(mean = mean(value), median=median(value)) %>%
        ungroup()
      
      cent_low_prev_p<- quantile(subRA_overall$value[which(subRA_overall$B_flock_status =="p" & substr(subRA_overall$variable, 1,4) == "Prev" )], probs=c(input$centile2[1]))
      cent_up_prev_p<- quantile(subRA_overall$value[which(subRA_overall$B_flock_status =="p" & substr(subRA_overall$variable, 1,4) == "Prev" )], probs=c(input$centile2[2]))
      
      cent_low_prev_n<- quantile(subRA_overall$value[which(subRA_overall$B_flock_status =="n" & substr(subRA_overall$variable, 1,4) == "Prev" )], probs=c(input$centile2[1]))
      cent_up_prev_n<- quantile(subRA_overall$value[which(subRA_overall$B_flock_status =="n" & substr(subRA_overall$variable, 1,4) == "Prev" )], probs=c(input$centile2[2]))
      
      cent_low_C_p<- quantile(subRA_overall$value[which(subRA_overall$B_flock_status =="p" & substr(subRA_overall$variable, 1,2) == "C_" & subRA_overall$variable !="C_prod_n")], probs=c(input$centile2[1]))
      cent_up_C_p<- quantile(subRA_overall$value[which(subRA_overall$B_flock_status =="p" & substr(subRA_overall$variable, 1,2) == "C_" & subRA_overall$variable !="C_prod_n")], probs=c(input$centile2[2]))
      
      cent_low_C_n<- quantile(subRA_overall$value[which(subRA_overall$B_flock_status =="n" & substr(subRA_overall$variable, 1,2) == "C_" & subRA_overall$variable !="C_prod_n")], probs=c(input$centile2[1]))
      cent_up_C_n<- quantile(subRA_overall$value[which(subRA_overall$B_flock_status =="n" & substr(subRA_overall$variable, 1,2) == "C_" & subRA_overall$variable !="C_prod_n")], probs=c(input$centile2[2]))
      
      p1<-subRA_overall%>%
        filter(B_flock_status =="p" & variable !="C_prod_n" & substr(variable, 1,4) == "Prev")%>%
        ggplot(aes(value)) +
        geom_density(fill = "red" , 
                     alpha = .3, col = NA) +
        geom_vline(aes(xintercept = mean, col = "Mean", linetype="Mean")) +
        geom_vline(aes(xintercept = median, col = "Median", linetype="Median")) +
        labs(y = "Density") +
        scale_x_continuous( limits = c(cent_low_prev_p, cent_up_prev_p)) +
        scale_color_manual(name = "Statistics", values = c(Median = "black", Mean = "black"))+
        scale_linetype_manual(name = "Statistics", values= c(Median = "dashed", Mean = "dotted"))+
        theme_bw()%+replace%
        theme(legend.position = "bottom")+
        ggtitle("Positive flocks - prevalence of contaminated products")+ 
        theme(axis.text.x = element_text(size=12),
              axis.text.y = element_text(size=12),
              axis.title.x = element_text(face="bold", size=14),
              axis.title.y = element_text(face="bold", size=14),
              strip.text = element_text(face="bold",size = 16),
              legend.text=element_text(size=12))
      
      p2<-subRA_overall%>%
        filter(B_flock_status =="p" & variable !="C_prod_n" & substr(variable, 1,2) == "C_")%>%
        ggplot(aes(value)) +
        geom_density(fill = "red" , 
                     alpha = .3, col = NA) +
        geom_vline(aes(xintercept = mean, col = "Mean", linetype="Mean")) +
        geom_vline(aes(xintercept = median, col = "Median", linetype="Median")) +
        labs(y = "Density") +
        scale_x_continuous( limits = c(cent_low_C_p, cent_up_C_p)) +
        scale_color_manual(name = "Statistics", values = c(Median = "black", Mean = "black"))+
        scale_linetype_manual(name = "Statistics", values= c(Median = "dashed", Mean = "dotted"))+
        theme_bw()%+replace%
        theme(legend.position = "bottom")+
        ggtitle("Positive flocks - bacteria contamination (CFU)")+ 
        theme(axis.text.x = element_text(size=12),
              axis.text.y = element_text(size=12),
              axis.title.x = element_text(face="bold", size=14),
              axis.title.y = element_text(face="bold", size=14),
              strip.text = element_text(face="bold",size = 16),
              legend.text=element_text(size=12))

      p3<-subRA_overall%>%
        filter(B_flock_status =="n" & variable !="C_prod_n" & substr(variable, 1,4) == "Prev")%>%
        ggplot(aes(value)) +
        geom_density(fill = "skyblue3" , 
                     alpha = .3, col = NA) +
        geom_vline(aes(xintercept = mean, col = "Mean", linetype="Mean")) +
        geom_vline(aes(xintercept = median, col = "Median", linetype="Median")) +
        labs(y = "Density") +
        scale_x_continuous( limits = c(cent_low_prev_n, cent_up_prev_n)) +
        scale_color_manual(name = "Statistics", values = c(Median = "black", Mean = "black"))+
        scale_linetype_manual(name = "Statistics", values= c(Median = "dashed", Mean = "dotted"))+
        theme_bw()%+replace%
        theme(legend.position = "bottom")+
        ggtitle("Negative flocks - prevalence contaminated products")+ 
        theme(axis.text.x = element_text(size=12),
              axis.text.y = element_text(size=12),
              axis.title.x = element_text(face="bold", size=14),
              axis.title.y = element_text(face="bold", size=14),
              strip.text = element_text(face="bold",size = 16),
              legend.text=element_text(size=12))
      
      p4<-subRA_overall%>%
        filter(B_flock_status =="n" & variable !="C_prod_n" & substr(variable, 1,2) == "C_")%>%
        ggplot(aes(value)) +
        geom_density(fill = "skyblue3" , 
                     alpha = .3, col = NA) +
        geom_vline(aes(xintercept = mean, col = "Mean", linetype="Mean")) +
        geom_vline(aes(xintercept = median, col = "Median", linetype="Median")) +
        labs(y = "Density") +
        scale_x_continuous( limits = c(cent_low_C_n, cent_up_C_n)) +
        scale_color_manual(name = "Statistics", values = c(Median = "black", Mean = "black"))+
        scale_linetype_manual(name = "Statistics", values= c(Median = "dashed", Mean = "dotted"))+
        theme_bw()%+replace%
        theme(legend.position = "bottom")+
        ggtitle("Negative flocks - bacteria contamination (CFU)")+ 
        theme(axis.text.x = element_text(size=12),
              axis.text.y = element_text(size=12),
              axis.title.x = element_text(face="bold", size=14),
              axis.title.y = element_text(face="bold", size=14),
              strip.text = element_text(face="bold",size = 16),
              legend.text=element_text(size=12))
      
      mylegend<-g_legend(p1)
      pr<- grid.arrange(arrangeGrob(p1+ theme(legend.position="none"),
                                    p2+ theme(legend.position="none"),
                                    p3+ theme(legend.position="none"),
                                    p4+ theme(legend.position="none"),
                                    nrow=1),
                        mylegend, nrow=2,heights=c(10, 1))  
      
      
      vals$p2 <- pr
      pr
      

    }
    
  })
  
  output$downloadPlot2 <- downloadHandler(
  #download plot 1/2
    filename = function(){paste('specificQAplot', input$Module_Risk,'.png', sep = '')},
    content = function(file){
      ggsave(file,vals$p2,
             width = 30, height = 12, dpi = 150, units = "cm")
    })
  output$get_plotRisk2 <- renderUI({ 
  #download plot 2/2
    req(calculatedVariables())
    data<-calculatedVariables()
    if(input$Product == "Chicken" & length(unique(data$B_flock_status)) !=1) {
      downloadButton("downloadPlot2", "Download Plot specific risk") 
    }
    
    })
  

  # correlation ANALYSIS TAB --------------------------------------------------------------------------------------------------------------------------
  
  correlationAnalysis <- eventReactive(input$buttoncorrelation, {
  #perform correlation analysis
    validate(
      need(input$Module_Risk!="","Please run calculation before performing a correlation analysis")
    )
    
    #read input file
    RA <- calculatedVariables()
    source("www/correlation_analysisShiny.R", local=TRUE)
    vals$saData <- SA
    SA
  })
  
  output$get_saData <- renderUI({ 
  #download raw data 1/2
    req(correlationAnalysis ())
    downloadButton('download_saData',"Download the results of the correlation analysis") })
  
  output$download_saData <- downloadHandler( 
    #download raw data 2/2
    filename = function(){paste("SAresults", input$Product, "_",input$Runs, "simulation.csv", sep="")}, 
    content = function(file){
      write.csv(vals$saData , file)
    }
  )
  
  output$moduleSelection_SA <- renderUI({
  #display module to be selected once the a button has been activated
    req(correlationAnalysis())
    selectInput(inputId="Module_SA", label="Select the module to be investigated", 
                choices= if(substr(input$Modules, 1,4) == "Proc"){
                  c("Processing", "Post-processing", "Home-preparation")
                } else if (substr(input$Modules, 1,4) == "Post"){
                  c("Post-processing", "Home-preparation")
                } else if (substr(input$Modules, 1,4) == "Home"){
                  c("Home preparation")
                }else{
                  c("Production","Processing", "Post-processing", "Home-preparation")
                }
    )
    
  })
  
  output$outcomeSA <- renderPlot({ 
  #SA of the selected module outcome
    req(correlationAnalysis())
    req(input$estimatedVariables)
    
    SA<-correlationAnalysis()

    if(input$Module_SA =="Production"){
      var <- c("Prev_prod","C_prod")

    }else if (input$Module_SA =="Processing"){
      var <- c("Prev_proc","C_proc")

    }else if (input$Module_SA =="Post-processing"){
      var <- c("Prev_pproc","C_pproc")

    }else{

      if(input$Product == "Chicken"){
        var <- c("Prev_home_cook","P_home_cc", "C_home_cook","C_home_cc")

      } else if(input$Product == "Lettuce"){
        var <- c("Prev_home_cook","C_home_cook")

      }

    }
    
    for (i in 1:length(var)){
      p<- SA %>%
        mutate(target = get(var[i]))%>%
        filter(target !=0 & abs(target) > 0.025)%>%
        ggplot(aes(x=target, y = reorder(variable, abs(target)), fill=target))+
        geom_bar(stat="identity")+
        xlab("Spearman coefficient")+
        ylab("Estimated variables")+
        ggtitle(var[i])+
        theme_light()+
        theme(legend.position = "none")+
        ylab("")+xlab("")+
        geom_vline(aes(xintercept = 0), colour="black", linetype="dashed") +
        scale_fill_gradient2(low='red', mid='snow3', high='darkgreen', space='Lab')
      assign( paste("p",i, sep=""), p)
    }
   
    if( length(var)==2){
      p<- grid.arrange(arrangeGrob(p1 + theme(legend.position="none")+xlab("Spearman coefficient"),
                               p2 + theme(legend.position="none")+xlab("Spearman coefficient"),
                               nrow=1))
      
    }else if (length(var)==4){
      p<- grid.arrange(arrangeGrob(p1 + theme(legend.position="none"),
                               p3 + theme(legend.position="none")+xlab("Spearman coefficient"),
                               p2 + theme(legend.position="none"),
                               p4 + theme(legend.position="none")+xlab("Spearman coefficient"),
                               nrow=2))
    }

    vals$p3 <- p
    p
    
  })
  
  output$downloadPlot3 <- downloadHandler(
  #download plot 1/2
    filename = function(){paste('SAplot_SpearmanCoef_', input$Module_SA,'.png', sep = '')},
    content = function(file){
      ggsave(file, vals$p3,
             width = 20, height = 8, dpi = 150, units = "cm")
      
    })
  output$get_plotRisk3 <- renderUI({ 
  #download plot 2/2
    req(correlationAnalysis())
    downloadButton("downloadPlot3", "Download Plot correlation analysis") })
  
}