#########################################################################################################################################
# FSA project FS307037 
# Development of a modular assessment framework to quantify the risk of AMR exposure via food products: example of chicken and lettuce
##########################################################################################################################################
# File Name:     Module_processingShiny_Lettuce.R
# Description:   Calculate variables associated with the processing module for the lettuce value chain

# Company:       Ausvet Eu
# Author:        Céline Faverjon
# Role:          Epidemiologist
# Email:         celine@ausvet.eu
# Date:          28.05.21
##########################################################################################################################################

#Food product: LETTUCE
##########################################################################################################################################

  #concentration in a lettuce after washing
  data$C_wash <- ifelse(data$Product_wash == "pre-washed",
                        data$C_prod*10^(-data$D_wash_proc),
                        data$C_prod)
  
  #CFU in a lettuce after washing
  data$N_wash <- data$C_wash * data$Prev_prod
  
  #number of cells transferred from lettuce to facility surfaces
  data$N_let_fac <- ifelse(data$Product_wash =="pre-washed" & data$Product_cut == "yes", 
                       data$N_wash*(data$TR_flume + data$TR_shred + data$TR_shake + data$TR_centri + data$TR_convey),
                       ifelse(Product_wash ==1 & Product_cut == 0, 
                              data$N_wash*data$TR_flume,
                              0
                       ))
  
  #number of cells transferred from facility surfaces to lettuce 
  data$N_fac_let <- ifelse(data$Product_wash =="pre-washed",
                        data$N_let_fac*data$TR_facility,
                        0)
  
  #number of cells in lettuce after processing 
  data$N_final <- data$N_wash - data$N_let_fac + data$N_fac_let
  
  #prevalenec of contaminated lettuce after cross-contamination
  data$Prev_proc <- ifelse(data$Product_wash =="pre-washed" & data$Product_cut == "yes", 
                           data$Prev_prod* data$TR_overall,
                           data$Prev_prod)
  
  #Product size, either size of a lettuce head or size of a bag of lettuce
  data$Size <- ifelse(data$Product_cut == "yes", 
                      data$Size_bag,
                      data$Size_mean)
  

  #concentration of bacteria after processing
  data$C_proc <- data$N_final /data$Prev_proc
  
 

  

