##########################################################################################################################################
# FSA project FS307037 
# Development of a modular assessment framework to quantify the risk of AMR exposure via food products: example of chicken and lettuce
##########################################################################################################################################
# File Name:     Module_productionShiny_Chicken.R
# Description:   Calculate variables associated with the production module for the chicken value chain

# Company:       Ausvet Eu
# Author:        Céline Faverjon
# Role:          Epidemiologist
# Email:         celine@ausvet.eu
# Date:          03.07.21
##########################################################################################################################################

#Food product: CHICKEN
##########################################################################################################################################

  #flock prevalence of AMR 
  data$Prev_f <- (1+data$F_AMU)*data$Prev_farm_type
  
  #flock status
  data$B_flock_status <- rbinom(input$Runs, 1, data$Prev_f)
  data$B_flock_status <- ifelse(data$B_flock_status ==1,"p","n")
  
  #flock status regarding thinning
  data$B_Thinning_status <- rbinom(input$Runs, 1, data$Prop_thinning)
  
  #increased within flock prevalence associated with thinning
  data$Prev_thinning <-ifelse(data$B_Thinning_status ==1,
                             (data$F_thinning*data$Prev_wfp_col_base)/(1+(data$F_thinning*data$Prev_wfp_col_base)-data$Prev_wfp_col_base),
                             data$Prev_wfp_col_base)
  
  #flock status regarding biosecurity measures
  data$B_Biosecurity_status <- rbinom(input$Runs, 1, data$Prop_biosecurity)
  
  #increased within flock prevalence associated with thinning
  data$Prev_biosecurity <-ifelse(data$B_Biosecurity_status ==1,
                                (data$F_biosecurity*data$Prev_thinning)/(1+(data$F_biosecurity*data$Prev_thinning)-data$Prev_thinning),
                                data$Prev_thinning)
  
  #flock age at slaughter
  data$B_Age_status <- rbinom(input$Runs, 1, data$Prop_age)
  
  #increased within flock prevalence associated with bird age
  data$Prev_age <-ifelse(data$B_Age_status ==1,
                        (data$F_age*data$Prev_biosecurity)/(1+(data$F_age*data$Prev_biosecurity)-data$Prev_biosecurity),
                        data$Prev_biosecurity)
  #season of slaughter
  data$B_Season_status <- rbinom(input$Runs, 1, data$Prop_season)
  
  #increased within flock prevalence associated with season
  data$Prev_season <-ifelse(data$B_Season_status ==1,
                           (data$F_season*data$Prev_age )/(1+(data$F_season*data$Prev_age )-data$Prev_age ),
                           data$Prev_age )
  
  #Prevalence of birds from positive flock internally colonized at pre-harvest(within flock prevalence)
  data$Prev_wfp_col <- data$Prev_season
  
  #number of bacteria on positive birds exterior at pre-harvest
  data$C_btp <- data$C_barn * data$Amount_fec
  
  #prevalence of birds externally colonized at pre-harvest
  data$Prev_wfp_ext <- rpert(input$Runs, 0.03, data$Prev_wfp_col , 0.9)
  
  #probability of carry-over from a positive flock transported earlier on that day
  data$P_ccbf <- (1 - (1 - data$Prev_f)^data$N_transp) * data$F_cross_trans
  
  #probability for cross-contamination to occur during transport
  data$P_ccwf <- 1 - (1- data$Prev_wfp_ext)^data$N_contact
  
  #Probablity a negative bird will become contaminated during transport
  data$P_pos <- data$P_ccwf + data$P_ccbf - (data$P_ccwf * data$P_ccbf)
  
  #Prevalence of externally contaminated birds after transport
  data$Prev_prod <- ifelse(data$B_flock_status=="p", 
                           data$Prev_wfp_ext + (1- data$Prev_wfp_ext) * data$P_pos,
                           data$P_ccbf)
  data$Prev_prod <- ifelse(data$Prev_prod >1,1, data$Prev_prod)
  
  #Number of bacteria on positive birds exterior after transport
  data$C_prod <- ifelse(data$B_flock_status=="p", 
                        data$C_btp * data$F_transp,
                        data$C_prod_n)

