##########################################################################################################################################
# FSA project FS307037 
# Development of a modular assessment framework to quantify the risk of AMR exposure via food products: example of chicken and lettuce
##########################################################################################################################################
# File Name:     Module_productionShiny_Lettuce.R
# Description:   Calculate variables associated with the production module for the lettuce value chain

# Company:       Ausvet Eu
# Author:        Céline Faverjon
# Role:          Epidemiologist
# Email:         celine@ausvet.eu
# Date:          28.05.21
##########################################################################################################################################

#Food product: LETTUCE
##########################################################################################################################################

  #concentration after irrigation
  data$C_pw <- data$C_water/100 * data$W_water
  
  #log reduction during holding time
  data$F_hold <- -(data$Time_hold/(2.45/24))^0.3
    
  #log concentration after holding time
  data$C_hold <- log(data$C_pw) + data$F_hold
  
  #season of harvesting
  data$B_season_status <- rbinom(input$Runs, 1, data$Prop_season)
  
  #increased within flock prevalence associated with high risk season
  data$F_season01 <- ifelse(data$B_season_status ==1,
                            (data$F_season* data$Prev_base)/(1- data$Prev_base + data$F_season*data$Prev_base),
                            data$Prev_base)
  
  #biosecurity practices
  data$B_biosecurity_status <- rbinom(input$Runs, 1, data$Prop_biosecurity)
  
  #increased within flock prevalence associated with high risk season
  data$F_biosecurity01 <- ifelse(data$B_biosecurity_status ==1,
                            (data$F_biosecurity * data$F_season01)/ (1 - data$F_season01+ (data$F_biosecurity * data$F_season01)) ,
                            data$F_season01)
  
  #farm using untreated manure
  data$B_fert_status <- rbinom(input$Runs, 1, data$Prop_fert)
  
  #increased prevalence associated with usage of untreated manure
  data$F_fert01 <- ifelse(data$B_fert_status ==1,
                          (data$F_fert * data$F_biosecurity01)/ (1 - data$F_biosecurity01+ (data$F_fert * data$F_biosecurity01)) ,
                          data$F_biosecurity01)
  
  #number of bacteria in soil attached on blade
  data$N_blade <- 10^data$C_soil * data$W_soil
  
  #prevalence of contaminated lettuce after harvesting
  data$Prev_harv <- data$F_fert01
  
  #concentration of bacteria in lettuce after harvest
  data$C_harv <- 10^data$C_hold + data$N_blade* data$TR_blade/(3*data$Size_mean)
  
  #prevalence of contaminated lettuce
  data$Prev_prod <- data$Prev_harv
  
  #Generation time in food product during field cooling
  data$Time_gen_field <- data$Time_gen_min/((data$T_field - data$T_growth_min)/(data$T_growth_opt - data$T_growth_min))^2
  
  #Growth factor G at field cooling
  data$G_field <- ifelse(data$T_field > data$T_growth_min, 
                          exp(log(2)/data$Time_gen_field * (data$Time_field)),
                          1)
  
  #concentration of bacteria in a contaminated lettuce after field cooling
  data$C_prod <- data$C_harv * data$G_field
  

