#########################################################################################################################################
# FSA project FS307037 
# Development of a modular assessment framework to quantify the risk of AMR exposure via food products: example of chicken and lettuce
##########################################################################################################################################
# File Name:     Sensitivity_analysis.R
# Description:   Run sensitivity analysis

# Company:       Ausvet Eu
# Author:        Céline Faverjon
# Role:          Epidemiologist
# Email:         celine@ausvet.eu
# Date:          05.07.21
##########################################################################################################################################

#Build output table
##########################################################################################################################################

df <- read_excel(input$estimatedVariables$datapath)

data_SA <- RA %>%
  summarise_if(is.numeric, mean, na.rm = TRUE) %>% 
  slice(rep(1:n(), each = input$Runs))
chr_var <- RA %>%
    select_if(is.character)
data_SA <-cbind(chr_var, data_SA)

if(substr(input$Modules, 1,4) == "Proc" ){
  estimatedVar<- c(df$Variable, "C_prod", "Prev_prod")
} else if (substr(input$Modules, 1,4) == "Post" ) {
  estimatedVar<- c(df$Variable, "C_proc", "Prev_proc")
} else if (substr(input$Modules, 1,4) == "Home" ) {
  estimatedVar<- c(df$Variable, "C_pproc", "Prev_pproc")
} else {
  estimatedVar<- df$Variable
}


if(input$Product == "Chicken"){
  if( substr(input$Modules, 1,4) == "Proc" ){
    outputVar<- c("Prev_proc","C_proc",
                  "Prev_pproc","C_pproc",
                  "C_home_cc", "C_home_cook", "Prev_home_cook", "P_home_cc")
    
  } else if (substr(input$Modules, 1,4) == "Post" ) {
    outputVar<- c("Prev_pproc","C_pproc",
                  "C_home_cc", "C_home_cook", "Prev_home_cook", "P_home_cc")
    
  } else if (substr(input$Modules, 1,4) == "Home" ) {
    outputVar<- c("C_home_cc", "C_home_cook", "Prev_home_cook", "P_home_cc")
    
  } else {
    outputVar<- c("Prev_prod","C_prod",
                  "Prev_proc","C_proc",
                  "Prev_pproc","C_pproc",
                  "C_home_cc", "C_home_cook", "Prev_home_cook", "P_home_cc")
  }
  
} else if(input$Product == "Lettuce"){
  
  if(substr(input$Modules, 1,4) == "Proc" ){
    outputVar<- c("Prev_proc","C_proc",
                  "Prev_pproc","C_pproc",
                  "Prev_home_cook", "C_home_cook")
    
  } else if (substr(input$Modules, 1,4) == "Post" ) {
    outputVar<- c("Prev_pproc","C_pproc",
                  "Prev_home_cook", "C_home_cook")
    
  } else if (substr(input$Modules, 1,4) == "Home" ) {
    outputVar<- c("Prev_home_cook", "C_home_cook")
    
  } else {
    outputVar<- c("Prev_prod","C_prod",
                  "Prev_proc","C_proc",
                  "Prev_pproc","C_pproc",
                  "Prev_home_cook", "C_home_cook")
  }
  
}


SA <- as.data.frame(matrix(0, ncol=length(outputVar), nrow= length(estimatedVar)))
rownames(SA)<- estimatedVar
colnames(SA)<- outputVar


# Module 1
##########################################################################################################################################
estimatedVarM<- df %>% 
  filter(Module=="Production") 
estimatedVarM<- unique(estimatedVarM$Variable)

if(input$Product == "Chicken"){
  if( substr(input$Modules, 1,4) == "Proc" ){
    outputVarM<- c("Prev_proc","C_proc",
                  "Prev_pproc","C_pproc",
                  "C_home_cc", "C_home_cook", "Prev_home_cook", "P_home_cc")
    
  } else if (substr(input$Modules, 1,4) == "Post" ) {
    outputVarM<- c("Prev_pproc","C_pproc",
                  "C_home_cc", "C_home_cook", "Prev_home_cook", "P_home_cc")
    
  } else if (substr(input$Modules, 1,4) == "Home" ) {
    outputVarM<- c("C_home_cc", "C_home_cook", "Prev_home_cook", "P_home_cc")
    
  } else {
    outputVarM<- c("Prev_prod","C_prod",
                  "Prev_proc","C_proc",
                  "Prev_pproc","C_pproc",
                  "C_home_cc", "C_home_cook", "Prev_home_cook", "P_home_cc")
  }
  
} else if(input$Product == "Lettuce"){
  
  if( substr(input$Modules, 1,4) == "Proc" ){
    outputVarM<- c("Prev_proc","C_proc",
                  "Prev_pproc","C_pproc",
                  "Prev_home_cook", "C_home_cook")
    
  } else if (substr(input$Modules, 1,4) == "Post" ) {
    outputVarM<- c("Prev_pproc","C_pproc",
                  "Prev_home_cook", "C_home_cook")
    
  } else if (substr(input$Modules, 1,4) == "Home" ) {
    outputVarM<- c("Prev_home_cook", "C_home_cook")
    
  } else {
    outputVarM<- c("Prev_prod","C_prod",
                  "Prev_proc","C_proc",
                  "Prev_pproc","C_pproc",
                  "Prev_home_cook", "C_home_cook")
  }
  
}

for(i in 1:length(estimatedVarM)){
  
 X<- as.data.frame(RA[,estimatedVarM[i]])
 colnames(X)<- estimatedVarM[i]
 
 if(sd(X[,1])!=0){
   Y<- data_SA %>%
     select(-estimatedVarM[i])
   data<- cbind(X,Y)
   
   if( substr(input$Modules, 1,4) == "Proc" ){
     source(paste0("www/Module_processingShiny_", input$Product, ".R"), local=TRUE)
     source(paste0("www/Module_postprocessingShiny_", input$Product, ".R"), local=TRUE)
     source(paste0("www/Module_homepreparationShiny_", input$Product, ".R"), local=TRUE)
     
   } else if (substr(input$Modules, 1,4) == "Post" ) {
     source(paste0("www/Module_postprocessingShiny_", input$Product, ".R"), local=TRUE)
     source(paste0("www/Module_homepreparationShiny_", input$Product, ".R"), local=TRUE)
     
   } else if (substr(input$Modules, 1,4) == "Home" ) {
     source(paste0("www/Module_homepreparationShiny_", input$Product, ".R"), local=TRUE)
     
   } else {
     source(paste0("www/Module_productionShiny_", input$Product, ".R"), local=TRUE)
     source(paste0("www/Module_processingShiny_", input$Product, ".R"), local=TRUE)
     source(paste0("www/Module_postprocessingShiny_", input$Product, ".R"), local=TRUE)
     source(paste0("www/Module_homepreparationShiny_", input$Product, ".R"), local=TRUE)
   }
   
   for (j in 1:length(outputVarM)){
     if(sd(data[,outputVarM[j]])!=0){
       SA[ estimatedVarM[i],outputVarM[j]] <- cor(data[,outputVarM[j]],data[,estimatedVarM[i]], method="spearman") 
     }
   }
 }


}

# Module 2
##########################################################################################################################################
estimatedVarM<- df %>% 
  filter(Module=="Processing") 
estimatedVarM<- unique(estimatedVarM$Variable)

if(input$Product == "Chicken"){
  if( substr(input$Modules, 1,4) == "Proc" ){
    outputVarM<- c("Prev_proc","C_proc",
                   "Prev_pproc","C_pproc",
                   "C_home_cc", "C_home_cook", "Prev_home_cook", "P_home_cc")
    estimatedVarM<- c(estimatedVarM,  "C_prod", "Prev_prod")
    
  } else if (substr(input$Modules, 1,4) == "Post" ) {
    outputVarM<- c("Prev_pproc","C_pproc",
                   "C_home_cc", "C_home_cook", "Prev_home_cook", "P_home_cc")
    estimatedVarM<- c(estimatedVarM,  "C_proc", "Prev_proc")
    
  } else if (substr(input$Modules, 1,4) == "Home" ) {
    outputVarM<- c("C_home_cc", "C_home_cook", "Prev_home_cook", "P_home_cc")
    estimatedVarM<- c(estimatedVarM,  "C_pproc", "Prev_pproc")
    
  } else {
    outputVarM<- c("Prev_proc","C_proc",
                   "Prev_pproc","C_pproc",
                   "C_home_cc", "C_home_cook", "Prev_home_cook", "P_home_cc")
  }
  
} else if(input$Product == "Lettuce"){
  
  if( substr(input$Modules, 1,4) == "Proc" ){
    outputVarM<- c("Prev_proc","C_proc",
                   "Prev_pproc","C_pproc",
                   "Prev_home_cook", "C_home_cook")
    estimatedVarM<- c(estimatedVarM,  "C_prod", "Prev_prod")
    
  } else if (substr(input$Modules, 1,4) == "Post" ) {
    outputVarM<- c("Prev_pproc","C_pproc",
                   "Prev_home_cook", "C_home_cook")
    estimatedVarM<- c(estimatedVarM,  "C_proc", "Prev_proc")
    
  } else if (substr(input$Modules, 1,4) == "Home" ) {
    outputVarM<- c("Prev_home_cook", "C_home_cook")
    estimatedVarM<- c(estimatedVarM,  "C_pproc", "Prev_pproc")
    
  } else {
    outputVarM<- c("Prev_proc","C_proc",
                   "Prev_pproc","C_pproc",
                   "Prev_home_cook", "C_home_cook")
  }
  
}

for(i in 1:length(estimatedVarM)){
  
  X<- as.data.frame(RA[,estimatedVarM[i]])
  colnames(X)<- estimatedVarM[i]
  
  if(sd(X[,1])!=0){
    Y<- data_SA %>%
      select(-estimatedVarM[i])
    data<- cbind(X,Y)
    
    #run modules
    if( substr(input$Modules, 1,4) == "Proc" ){
      source(paste0("www/Module_processingShiny_", input$Product, ".R"), local=TRUE)
      source(paste0("www/Module_postprocessingShiny_", input$Product, ".R"), local=TRUE)
      source(paste0("www/Module_homepreparationShiny_", input$Product, ".R"), local=TRUE)
      
    } else if (substr(input$Modules, 1,4) == "Post" ) {
      source(paste0("www/Module_postprocessingShiny_", input$Product, ".R"), local=TRUE)
      source(paste0("www/Module_homepreparationShiny_", input$Product, ".R"), local=TRUE)
      
    } else if (substr(input$Modules, 1,4) == "Home" ) {
      source(paste0("www/Module_homepreparationShiny_", input$Product, ".R"), local=TRUE)
      
    } else {
      source(paste0("www/Module_productionShiny_", input$Product, ".R"), local=TRUE)
      source(paste0("www/Module_processingShiny_", input$Product, ".R"), local=TRUE)
      source(paste0("www/Module_postprocessingShiny_", input$Product, ".R"), local=TRUE)
      source(paste0("www/Module_homepreparationShiny_", input$Product, ".R"), local=TRUE)
    }
    
    for (j in 1:length(outputVarM)){
      if(sd(data[,outputVarM[j]])!=0){
        SA[ estimatedVarM[i],outputVarM[j]] <- cor(data[,outputVarM[j]],data[,estimatedVarM[i]], method="spearman") 
      }
    }
  }

}

# Module 3
##########################################################################################################################################
estimatedVarM<- df %>% 
  filter(Module=="Post-processing") 
estimatedVarM<- unique(estimatedVarM$Variable)


if(input$Product == "Chicken"){
  if( substr(input$Modules, 1,4) == "Proc" ){
    outputVarM<- c("Prev_pproc","C_pproc",
                   "C_home_cc", "C_home_cook", "Prev_home_cook", "P_home_cc")
    estimatedVarM<- c(estimatedVarM,  "C_prod", "Prev_prod")
    
  } else if (substr(input$Modules, 1,4) == "Post" ) {
    outputVarM<- c("Prev_pproc","C_pproc",
                   "C_home_cc", "C_home_cook", "Prev_home_cook", "P_home_cc")
    estimatedVarM<- c(estimatedVarM,  "C_proc", "Prev_proc")
    
  } else if (substr(input$Modules, 1,4) == "Home" ) {
    outputVarM<- c("C_home_cc", "C_home_cook", "Prev_home_cook", "P_home_cc")
    estimatedVarM<- c(estimatedVarM,  "C_pproc", "Prev_pproc")
    
  } else {
    outputVarM<- c("Prev_pproc","C_pproc",
                   "C_home_cc", "C_home_cook", "Prev_home_cook", "P_home_cc")
  }
  
} else if(input$Product == "Lettuce"){
  
  if( substr(input$Modules, 1,4) == "Proc" ){
    outputVarM<- c("Prev_pproc","C_pproc",
                   "Prev_home_cook", "C_home_cook")
    estimatedVarM<- c(estimatedVarM,  "C_prod", "Prev_prod")
    
  } else if (substr(input$Modules, 1,4) == "Post" ) {
    outputVarM<- c("Prev_pproc","C_pproc",
                   "Prev_home_cook", "C_home_cook")
    estimatedVarM<- c(estimatedVarM,  "C_proc", "Prev_proc")
    
  } else if (substr(input$Modules, 1,4) == "Home" ) {
    outputVarM<- c("Prev_home_cook", "C_home_cook")
    estimatedVarM<- c(estimatedVarM,  "C_pproc", "Prev_pproc")
    
  } else {
    outputVarM<- c("Prev_pproc","C_pproc",
                   "Prev_home_cook", "C_home_cook")
  }
  
}
  


for(i in 1:length(estimatedVarM)){
  
  X<- as.data.frame(RA[,estimatedVarM[i]])
  colnames(X)<- estimatedVarM[i]
  
  if(sd(X[,1])!=0){
    Y<- data_SA %>%
      select(-estimatedVarM[i])
    data<- cbind(X,Y)
    
    #run modules
    if( substr(input$Modules, 1,4) == "Proc" ){
      source(paste0("www/Module_processingShiny_", input$Product, ".R"), local=TRUE)
      source(paste0("www/Module_postprocessingShiny_", input$Product, ".R"), local=TRUE)
      source(paste0("www/Module_homepreparationShiny_", input$Product, ".R"), local=TRUE)
      
    } else if (substr(input$Modules, 1,4) == "Post" ) {
      source(paste0("www/Module_postprocessingShiny_", input$Product, ".R"), local=TRUE)
      source(paste0("www/Module_homepreparationShiny_", input$Product, ".R"), local=TRUE)
      
    } else if (substr(input$Modules, 1,4) == "Home" ) {
      source(paste0("www/Module_homepreparationShiny_", input$Product, ".R"), local=TRUE)
      
    } else {
      source(paste0("www/Module_productionShiny_", input$Product, ".R"), local=TRUE)
      source(paste0("www/Module_processingShiny_", input$Product, ".R"), local=TRUE)
      source(paste0("www/Module_postprocessingShiny_", input$Product, ".R"), local=TRUE)
      source(paste0("www/Module_homepreparationShiny_", input$Product, ".R"), local=TRUE)
    }
    
    for (j in 1:length(outputVarM)){
      if(sd(data[,outputVarM[j]])!=0){
        SA[ estimatedVarM[i],outputVarM[j]] <- cor(data[,outputVarM[j]],data[,estimatedVarM[i]], method="spearman") 
      }
    }
  }
  
  
}
# Module 4
##########################################################################################################################################
estimatedVarM<- df %>% 
  filter(Module=="Home-preparation") 
estimatedVarM<- unique(estimatedVarM$Variable)


if(input$Product == "Chicken"){
  outputVarM<- c("C_home_cc", "C_home_cook", "Prev_home_cook", "P_home_cc")
  
  if( substr(input$Modules, 1,4) == "Proc" ){
    estimatedVarM<- c(estimatedVarM,  "C_prod", "Prev_prod")
    
  } else if (substr(input$Modules, 1,4) == "Post" ) {
    estimatedVarM<- c(estimatedVarM,  "C_proc", "Prev_proc")
    
  } else if (substr(input$Modules, 1,4) == "Home" ) {
    estimatedVarM<- c(estimatedVarM,  "C_pproc", "Prev_pproc")
    
  } 
  
} else if(input$Product == "Lettuce"){
  outputVarM<- c( "Prev_home_cook", "C_home_cook")
  
  if( substr(input$Modules, 1,4) == "Proc" ){
    estimatedVarM<- c(estimatedVarM,  "C_prod", "Prev_prod")
    
  } else if (substr(input$Modules, 1,4) == "Post" ) {
    estimatedVarM<- c(estimatedVarM,  "C_proc", "Prev_proc")
    
  } else if (substr(input$Modules, 1,4) == "Home" ) {
    estimatedVarM<- c(estimatedVarM,  "C_pproc", "Prev_pproc")
    
  } 
  
}


for(i in 1:length(estimatedVarM)){
  
  X<- as.data.frame(RA[,estimatedVarM[i]])
  colnames(X)<- estimatedVarM[i]

  if(sd(X[,1])!=0){
    Y<- data_SA %>%
      select(-estimatedVarM[i])
    data<- cbind(X,Y)

    #run modules
    if( substr(input$Modules, 1,4) == "Proc" ){
      source(paste0("www/Module_processingShiny_", input$Product, ".R"), local=TRUE)
      source(paste0("www/Module_postprocessingShiny_", input$Product, ".R"), local=TRUE)
      source(paste0("www/Module_homepreparationShiny_", input$Product, ".R"), local=TRUE)
      
    } else if (substr(input$Modules, 1,4) == "Post" ) {
      source(paste0("www/Module_postprocessingShiny_", input$Product, ".R"), local=TRUE)
      source(paste0("www/Module_homepreparationShiny_", input$Product, ".R"), local=TRUE)
      
    } else if (substr(input$Modules, 1,4) == "Home" ) {
      source(paste0("www/Module_homepreparationShiny_", input$Product, ".R"), local=TRUE)
      
    } else {
      source(paste0("www/Module_productionShiny_", input$Product, ".R"), local=TRUE)
      source(paste0("www/Module_processingShiny_", input$Product, ".R"), local=TRUE)
      source(paste0("www/Module_postprocessingShiny_", input$Product, ".R"), local=TRUE)
      source(paste0("www/Module_homepreparationShiny_", input$Product, ".R"), local=TRUE)
    }
    
    for (j in 1:length(outputVarM)){
      if(sd(data[,outputVarM[j]])!=0){
        SA[ estimatedVarM[i],outputVarM[j]] <- cor(data[,outputVarM[j]],data[,estimatedVarM[i]], method="spearman") 
      }
    }
  }
  
}

SA$variable <- rownames(SA)
